# Task Scheduler

The task scheduler [TaskScheduler][fluid.scheduler.TaskScheduler] inherits
from the [TaskConsumer][fluid.scheduler.TaskConsumer] to add scheduling of
periodic tasks.

It can be imported from `fluid.scheduler`:

```python
from fluid.scheduler import TaskScheduler
```

::: fluid.scheduler.TaskScheduler
